==> estateplat-common-1.2.4-20250303.011930-1291-sources.jar: cn/gtmap/estateplat/model/exchange/national/nmg/DjfDjZs.java <==
package cn.gtmap.estateplat.model.exchange.national.nmg;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 登记项目业务信息
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/12/24
 */
@Table(name = "djf_dj_zs")
public class DjfDjZs implements Serializable {
    //业务号，全局唯一、当前登记项目的业务号（主键）
    @Id
    private String zsid;
    private String bdcqzh;
    private String ywh;
    private String bh;
    private String zzbs;
    private String djjg;
    private String djjgdm;
    private Date djsj;
    private String dwdm;
    private String qlr;
    private String ywr;
    private String gyqk;
    private String zl;
    private String bdcdyh;
    private String qllx;
    private String qllxdm;
    private String qlxz;
    private String qlxzdm;
    private String yt;
    private String mj;
    private String syqx;
    private String qlqtzk;
    private String fj;
    private String qszt;
    private String zstype;
    private String zmqlsx;
    private Date syqxq;
    private Date syqxz;

    public String getBh() {
        return bh;
    }

    public void setBh(String bh) {
        this.bh = bh;
    }

    public String getZsid() {
        return zsid;
    }

    public void setZsid(String zsid) {
        this.zsid = zsid;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getZzbs() {
        return zzbs;
    }

    public void setZzbs(String zzbs) {
        this.zzbs = zzbs;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getDjjgdm() {
        return djjgdm;
    }

    public void setDjjgdm(String djjgdm) {
        this.djjgdm = djjgdm;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getYwr() {
        return ywr;
    }

    public void setYwr(String ywr) {
        this.ywr = ywr;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getQllxdm() {
        return qllxdm;
    }

    public void setQllxdm(String qllxdm) {
        this.qllxdm = qllxdm;
    }

    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }

    public String getQlxzdm() {
        return qlxzdm;
    }

    public void setQlxzdm(String qlxzdm) {
        this.qlxzdm = qlxzdm;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getMj() {
        return mj;
    }

    public void setMj(String mj) {
        this.mj = mj;
    }

    public String getSyqx() {
        return syqx;
    }

    public void setSyqx(String syqx) {
        this.syqx = syqx;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getZstype() {
        return zstype;
    }

    public void setZstype(String zstype) {
        this.zstype = zstype;
    }

    public String getZmqlsx() {
        return zmqlsx;
    }

    public void setZmqlsx(String zmqlsx) {
        this.zmqlsx = zmqlsx;
    }

    public Date getSyqxq() {
        return syqxq;
    }

    public void setSyqxq(Date syqxq) {
        this.syqxq = syqxq;
    }

    public Date getSyqxz() {
        return syqxz;
    }

    public void setSyqxz(Date syqxz) {
        this.syqxz = syqxz;
    }
}

==> estateplat-common-1.2.4-20251027.081413-1311-sources.jar: cn/gtmap/estateplat/model/exchange/national/nmg/DjfDjZs.java <==
package cn.gtmap.estateplat.model.exchange.national.nmg;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 登记项目业务信息
 *
 * @author <a href="mailto:shenjian@gtmap.cn">jane</a>
 * @version 1.0, 2015/12/24
 */
@Table(name = "djf_dj_zs")
public class DjfDjZs implements Serializable {
    //业务号，全局唯一、当前登记项目的业务号（主键）
    @Id
    private String zsid;
    private String bdcqzh;
    private String ywh;
    private String bh;
    private String zzbs;
    private String djjg;
    private String djjgdm;
    private Date djsj;
    private String dwdm;
    private String qlr;
    private String ywr;
    private String gyqk;
    private String zl;
    private String bdcdyh;
    private String qllx;
    private String qllxdm;
    private String qlxz;
    private String qlxzdm;
    private String yt;
    private String mj;
    private String syqx;
    private String qlqtzk;
    private String fj;
    private String qszt;
    private String zstype;
    private String zmqlsx;
    private Date syqxq;
    private Date syqxz;
    private Date updatetime;
    private Date createtime;


    public Date getUpdatetime() {
        return updatetime;
    }

    public void setUpdatetime(Date updatetime) {
        this.updatetime = updatetime;
    }

    public Date getCreatetime() {
        return createtime;
    }

    public void setCreatetime(Date createtime) {
        this.createtime = createtime;
    }

    public String getBh() {
        return bh;
    }

    public void setBh(String bh) {
        this.bh = bh;
    }

    public String getZsid() {
        return zsid;
    }

    public void setZsid(String zsid) {
        this.zsid = zsid;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getZzbs() {
        return zzbs;
    }

    public void setZzbs(String zzbs) {
        this.zzbs = zzbs;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getDjjgdm() {
        return djjgdm;
    }

    public void setDjjgdm(String djjgdm) {
        this.djjgdm = djjgdm;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getYwr() {
        return ywr;
    }

    public void setYwr(String ywr) {
        this.ywr = ywr;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getQllxdm() {
        return qllxdm;
    }

    public void setQllxdm(String qllxdm) {
        this.qllxdm = qllxdm;
    }

    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }

    public String getQlxzdm() {
        return qlxzdm;
    }

    public void setQlxzdm(String qlxzdm) {
        this.qlxzdm = qlxzdm;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getMj() {
        return mj;
    }

    public void setMj(String mj) {
        this.mj = mj;
    }

    public String getSyqx() {
        return syqx;
    }

    public void setSyqx(String syqx) {
        this.syqx = syqx;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getZstype() {
        return zstype;
    }

    public void setZstype(String zstype) {
        this.zstype = zstype;
    }

    public String getZmqlsx() {
        return zmqlsx;
    }

    public void setZmqlsx(String zmqlsx) {
        this.zmqlsx = zmqlsx;
    }

    public Date getSyqxq() {
        return syqxq;
    }

    public void setSyqxq(Date syqxq) {
        this.syqxq = syqxq;
    }

    public Date getSyqxz() {
        return syqxz;
    }

    public void setSyqxz(Date syqxz) {
        this.syqxz = syqxz;
    }
}
